attck_cdf_tactic: Product an ATT&CK Cumulative Distribution Function by Tactic

Description Usage Arguments

View source: R/atck-cdf.R

Description

Product an ATT&CK Cumulative Distribution Function by Tactic

Usage

1
attck_cdf_tactic(xdf, input = NULL, output = NULL, matrix = NULL, ...)

Arguments

xdf

a data frame with tactic, technique and value columns. If no value column exists, then the function will assume you have passed in individual events and will perform a "count" summarization before generating the heatmap.

input, output, matrix

if both are not NULL then they should be what fct_tactic() takes as parameters. Otherwise, the function will assume that the tactic column is already an ordered factor.

...

passed on to ggplot2::geom_label()


hrbrmstr/attckr documentation built on Aug. 13, 2020, 11:49 a.m.