attckr: Analyze Adversary Tactics and Techniques Using the MITRE...

Description Author(s) See Also

Description

MITRE ATT&CK™ is a globally-accessible knowledge base of adversary tactics and techniques based on real-world observations. The ATT&CK knowledge base is used as a foundation for the development of specific threat models and methodologies in the private sector, in government, and in the cybersecurity product and service community. Tools are provided to analyze adversary tactics and techniques, build incident metrics, and identify high level program gaps using the MITRE ATT&CK CTI Corpus.

Author(s)

Bob Rudis (bob@rud.is)

See Also

Useful links:


hrbrmstr/attckr documentation built on Aug. 13, 2020, 11:49 a.m.